==> org-lsst-ccs-subsystem-fcs-main-4.0.2-sources.jar: org/lsst/ccs/subsystems/fcs/simulation/SimuAutochangerOnlineClampController.java <==
/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package org.lsst.ccs.subsystems.fcs.simulation;

import java.util.Map;
import org.lsst.ccs.commons.annotations.ConfigurationParameter;
import org.lsst.ccs.description.ComponentLookup;
import org.lsst.ccs.subsystems.fcs.AutochangerOnlineClampModule;
import org.lsst.ccs.subsystems.fcs.common.EPOSControllerWithBrake;

/**
 * To simulate a controller which opens and closes a ONLINE clamp on the autochanger.
 * @author virieux
 */
public class SimuAutochangerOnlineClampController extends SimuEPOSControllerModule implements EPOSControllerWithBrake {
    
    @ConfigurationParameter(isFinal = true)
    private String onlineClampName;
    
    private SimuAutochangerPlutoGateway plutoGateway;
    private String plutoGatewayName;
    
    private AutochangerOnlineClampModule onlineClamp;
    


    /**
     * Build a new SimuAutochangerOnlineClampController.
     * @param nodeID
     * @param serialNB
     * @param onlineClampName
     * @param paramsForCurrent
     * @param paramsForProfilePosition
     * @param paramsForHoming 
     */
    public SimuAutochangerOnlineClampController(
            String nodeID, String serialNB,
            String onlineClampName,
            Map<String, Integer> paramsForCurrent,
            Map<String, Integer> paramsForProfilePosition,
            Map<String, Integer> paramsForHoming) {
        super(nodeID, serialNB,
                paramsForCurrent, paramsForProfilePosition, paramsForHoming);
        this.onlineClampName = onlineClampName;
        this.plutoGatewayName = "acSensorsGateway";
    }
    
    @Override
    public void initModule() {
        super.initModule();
        ComponentLookup lookup = getComponentLookup();
        this.plutoGateway = (SimuAutochangerPlutoGateway) lookup.getComponentByName(plutoGatewayName);
        this.onlineClamp = (AutochangerOnlineClampModule) lookup.getComponentByName(onlineClampName);
    }
    
    /**
     * Quick and dirty simulation.
     * This will have to be refactorized after tests on the real hardware.
     * 
     * @param current 
     */
    @Override
    public void writeCurrent(int current) {
        this.targetCurrent = current;
        this.actualCurrent = current;
        if (targetCurrent == onlineClamp.getCurrentToClose()) {

            plutoGateway.simulateAutochangerOnlineClampIsClosed(onlineClamp);
            
        } else if(targetCurrent == onlineClamp.getCurrentToOpen()) {

            plutoGateway.simulateAutochangerOnlineClampIsOpened(onlineClamp);
            
        } else if(targetCurrent == onlineClamp.getCurrentToClamp()) {

            plutoGateway.simulateAutochangerOnlineClampIsLocked(onlineClamp);
        }
    }

    @Override
    public void activateBrakeAndDisable() {
    }

    @Override
    public void enableAndReleaseBrake() {
    }

    @Override
    public void doReleaseBrake() {
    }
    


}

==> org-lsst-ccs-subsystem-fcs-main-4.0.12-sources.jar: org/lsst/ccs/subsystems/fcs/simulation/SimuAutochangerOnlineClampController.java <==

package org.lsst.ccs.subsystems.fcs.simulation;

import java.util.Map;
import org.lsst.ccs.commons.annotations.ConfigurationParameter;
import org.lsst.ccs.description.ComponentLookup;
import org.lsst.ccs.subsystems.fcs.AutochangerOnlineClamp;
import org.lsst.ccs.subsystems.fcs.common.EPOSControllerWithBrake;

/**
 * To simulate a controller which opens and closes a ONLINE clamp on the autochanger.
 * @author virieux
 */
public class SimuAutochangerOnlineClampController extends SimuEPOSControllerModule implements EPOSControllerWithBrake {
    
    @ConfigurationParameter(isFinal = true)
    private String onlineClampName;
    
    private final SimuAutochangerPlutoGateway plutoGateway;
    
    private AutochangerOnlineClamp onlineClamp;
    
    private boolean brakeActivated;

    /**
     * Build a new SimuAutochangerOnlineClampController.
     * @param nodeID
     * @param serialNB
     * @param plutoGateway
     * @param onlineClampName
     * @param paramsForCurrent
     * @param paramsForProfilePosition
     * @param paramsForHoming 
     */
    public SimuAutochangerOnlineClampController(
            int nodeID, String serialNB,
            SimuAutochangerPlutoGateway plutoGateway,
            String onlineClampName,
            Map<String, Integer> paramsForCurrent,
            Map<String, Integer> paramsForProfilePosition,
            Map<String, Integer> paramsForHoming) {
        super(nodeID, serialNB,
                paramsForCurrent, paramsForProfilePosition, paramsForHoming);
        this.onlineClampName = onlineClampName;
        this.plutoGateway = plutoGateway;
    }
    
    @Override
    public void init() {
        ComponentLookup lookup = getComponentLookup();
        this.onlineClamp = (AutochangerOnlineClamp) lookup.getComponentByName(onlineClampName);
    }
    
    /**
     * Quick and dirty simulation.
     * This will have to be refactorized after tests on the real hardware.
     * 
     * @param current 
     */
    @Override
    public void writeCurrent(int current) {
        this.targetCurrent = current;
        this.actualCurrent = current;
        if (targetCurrent == onlineClamp.getFinalCurrentToClose()) {

            plutoGateway.simulateAutochangerOnlineClampIsClosed(onlineClamp);
            
        } else if(targetCurrent == onlineClamp.getCurrentToOpen()) {

            plutoGateway.simulateAutochangerOnlineClampIsOpened(onlineClamp);
            
        } else if(targetCurrent == onlineClamp.getCurrentToClamp()) {

            plutoGateway.simulateAutochangerOnlineClampIsLocked(onlineClamp);
        }
    }

    @Override
    public void activateBrakeAndDisable() {
        brakeActivated = true;
    }

    @Override
    public void enableAndReleaseBrake() {
        brakeActivated = false;
    }

    @Override
    public void doReleaseBrake() {
        brakeActivated = false;
    }

    @Override
    public boolean isBrakeActivated() {
        return brakeActivated;
    }

    @Override
    public void activateBrake() {
        brakeActivated = true;
    }
    


}
